==> gnustep-base_1.24.9.orig.tar.gz: gnustep-base-1.24.9/Tests/base/NSLock/RecursiveLock.m <==
#import <Foundation/Foundation.h>
#import "Testing.h"

int main()
{
  NSAutoreleasePool   *arp = [NSAutoreleasePool new];
  BOOL ret;
  NSLock *lock = [NSRecursiveLock new];

  ret = [lock tryLock];
  if (ret)
    [lock unlock];
  PASS(ret, "NSRecursiveLock with tryLock, then unlocking");
  
  ret = [lock lockBeforeDate: [NSDate dateWithTimeIntervalSinceNow:1]];
  if (ret)
    [lock unlock];
  PASS(ret, "NSRecursiveLock lockBeforeDate: works");
  
  ret = [lock tryLock];
  if (ret)
    {
      ret = [lock lockBeforeDate: [NSDate dateWithTimeIntervalSinceNow:1]];
      if (ret)
        {
          [lock unlock];
        }
      [lock unlock];
    }
  PASS(ret, "NSRecursiveLock lockBeforeDate: with NSRecursiveLock returns YES");

#if     defined(GNUSTEP_BASE_LIBRARY)
  START_SET("mutex ownership extension")
#if     defined(_WIN32)
  SKIP("mutex ownership feature not available on windows")
#endif
  NS_DURING
    {
      PASS([lock isLockedByCurrentThread] == NO,
        "NSRecursiveLock isLockedByCurrentThread returns NO when not locked");
      [lock lock];
      PASS([lock isLockedByCurrentThread] == YES,
        "NSRecursiveLock isLockedByCurrentThread returns YES when locked");
      [lock unlock];
      PASS([lock isLockedByCurrentThread] == NO,
        "NSRecursiveLock isLockedByCurrentThread returns NO when unlocked");
    }
  NS_HANDLER
    {
      NSLog(@"-isLockedByCurrentThread not supported");
    }
  NS_ENDHANDLER
  END_SET("mutex ownership extension")
#endif

  [arp release]; arp = nil;
  return 0;
}

==> gnustep-base_1.29.0.orig.tar.gz: gnustep-base-1.29.0/Tests/base/NSLock/RecursiveLock.m <==
#import <Foundation/Foundation.h>
#import "../../../Headers/GNUstepBase/config.h"
#import "Testing.h"

int main()
{
  NSAutoreleasePool   *arp = [NSAutoreleasePool new];
  BOOL ret;
  NSLock *lock = [NSRecursiveLock new];

  ret = [lock tryLock];
  if (ret)
    [lock unlock];
  PASS(ret, "NSRecursiveLock with tryLock, then unlocking");
  
  ret = [lock lockBeforeDate: [NSDate dateWithTimeIntervalSinceNow:1]];
  if (ret)
    [lock unlock];
  PASS(ret, "NSRecursiveLock lockBeforeDate: works");
  
  ret = [lock tryLock];
  if (ret)
    {
      ret = [lock lockBeforeDate: [NSDate dateWithTimeIntervalSinceNow:1]];
      if (ret)
        {
          [lock unlock];
        }
      [lock unlock];
    }
  PASS(ret, "NSRecursiveLock lockBeforeDate: with NSRecursiveLock returns YES");

#if     defined(GNUSTEP_BASE_LIBRARY)
  START_SET("mutex ownership extension")
#if     !defined(HAVE_PTHREAD_MUTEX_OWNER)
  SKIP("mutex ownership feature not available")
#endif
  NS_DURING
    {
      testHopeful = YES;
      PASS([lock isLockedByCurrentThread] == NO,
        "NSRecursiveLock isLockedByCurrentThread returns NO when not locked");
      [lock lock];
      PASS([lock isLockedByCurrentThread] == YES,
        "NSRecursiveLock isLockedByCurrentThread returns YES when locked");
      [lock unlock];
      PASS([lock isLockedByCurrentThread] == NO,
        "NSRecursiveLock isLockedByCurrentThread returns NO when unlocked");
      testHopeful = NO;
    }
  NS_HANDLER
    {
      NSLog(@"-isLockedByCurrentThread not supported");
    }
  NS_ENDHANDLER
  END_SET("mutex ownership extension")
#endif

  [arp release]; arp = nil;
  return 0;
}
